# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SchemaMessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14SchemaMessages.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x01\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\tdata_type\x18\x02 \x01(\x0e\x32\x11.xgt.UvalTypeEnum\x12\x1b\n\x04role\x18\x03 \x01(\x0e\x32\r.xgt.RoleEnum\x12$\n\tleaf_type\x18\x04 \x01(\x0e\x32\x11.xgt.UvalTypeEnum\x12\x12\n\nlist_depth\x18\x05 \x01(\x04\")\n\x06Schema\x12\x1f\n\x08property\x18\x01 \x03(\x0b\x32\r.xgt.Property\"7\n\nTableFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\"8\n\x0bVertexFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\"\x8c\x01\n\tEdgeFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\x12\x15\n\rsource_vertex\x18\x03 \x01(\t\x12\x15\n\rtarget_vertex\x18\x04 \x01(\t\x12\x12\n\nsource_key\x18\x05 \x01(\t\x12\x12\n\ntarget_key\x18\x06 \x01(\t\"\xc7\x01\n\x08\x41nyFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\x12\x15\n\rsource_vertex\x18\x03 \x01(\t\x12\x15\n\rtarget_vertex\x18\x04 \x01(\t\x12\x12\n\nsource_key\x18\x05 \x01(\t\x12\x12\n\ntarget_key\x18\x06 \x01(\t\x12\x14\n\x0c\x63ontainer_id\x18\x08 \x01(\x04\x12\x11\n\tcommit_id\x18\t \x01(\x04\x12\x11\n\tdelete_id\x18\n \x01(\x04\"\xc3\x01\n\x10QueryEdgeMessage\x12/\n\x0e\x65\x64ge_direction\x18\x01 \x01(\x0e\x32\x17.xgt.QueryEdgeDirection\x12\x12\n\nedge_label\x18\x02 \x01(\t\x12\x12\n\nedge_frame\x18\x03 \x01(\t\x12\x14\n\x0csource_label\x18\x04 \x01(\t\x12\x14\n\x0csource_frame\x18\x05 \x01(\t\x12\x14\n\x0ctarget_label\x18\x06 \x01(\t\x12\x14\n\x0ctarget_frame\x18\x07 \x01(\t\"]\n\rQueryEdgeList\x12$\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x15.xgt.QueryEdgeMessage\x12\x17\n\nplan_score\x18\x02 \x01(\x01H\x00\x88\x01\x01\x42\r\n\x0b_plan_score\":\n\tQueryPlan\x12-\n\x11plan_as_edge_list\x18\x01 \x03(\x0b\x32\x12.xgt.QueryEdgeList\"\xe1\x03\n\tJobStatus\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0e\n\x06job_id\x18\x02 \x01(\x04\x12\"\n\x06status\x18\x03 \x01(\x0e\x32\x12.xgt.JobStatusEnum\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x37\n\rvisited_edges\x18\x08 \x03(\x0b\x32 .xgt.JobStatus.VisitedEdgesEntry\x12\x0e\n\x06timing\x18\t \x03(\t\x12\x1b\n\x06schema\x18\n \x01(\x0b\x32\x0b.xgt.Schema\x12\x12\n\ntotal_rows\x18\x0b \x01(\x04\x12\"\n\nquery_plan\x18\x0c \x01(\x0b\x32\x0e.xgt.QueryPlan\x12\x1b\n\x13total_ingest_errors\x18\r \x01(\x04\x12\x14\n\x0cingest_error\x18\x0e \x03(\t\x1a\x33\n\x11VisitedEdgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01*\xd0\x01\n\x0cUvalTypeEnum\x12\x15\n\x11UNKNOWN_UVAL_TYPE\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\x0c\n\x08\x44\x41TETIME\x10\x07\x12\r\n\tIPADDRESS\x10\x08\x12\x08\n\x04TEXT\x10\t\x12\x10\n\x0c\x43ONTAINER_ID\x10\n\x12\n\n\x06JOB_ID\x10\x0b\x12\x08\n\x04LIST\x10\x0c\x12\n\n\x06ROW_ID\x10\r\x12\x0c\n\x08\x44URATION\x10\x0e*q\n\x08RoleEnum\x12\x0c\n\x08PROPERTY\x10\x00\x12\x0e\n\nVERTEX_KEY\x10\x01\x12\x13\n\x0f\x45\x44GE_SOURCE_KEY\x10\x02\x12\x13\n\x0f\x45\x44GE_TARGET_KEY\x10\x03\x12\x1d\n\x19\x41SSOCIATIVE_CONTAINER_KEY\x10\x04*F\n\rFrameTypeEnum\x12\t\n\x05TABLE\x10\x00\x12\n\n\x06VERTEX\x10\x01\x12\x08\n\x04\x45\x44GE\x10\x02\x12\x14\n\x10UVAL_ASSOCIATIVE\x10\x03*z\n\rJobStatusEnum\x12\x16\n\x12UNKNOWN_JOB_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08ROLLBACK\x10\x06*=\n\x12QueryEdgeDirection\x12\x0b\n\x07\x46ORWARD\x10\x00\x12\x0c\n\x08\x42\x41\x43KWARD\x10\x01\x12\x0c\n\x08NOT_EDGE\x10\x02\x62\x06proto3')

_UVALTYPEENUM = DESCRIPTOR.enum_types_by_name['UvalTypeEnum']
UvalTypeEnum = enum_type_wrapper.EnumTypeWrapper(_UVALTYPEENUM)
_ROLEENUM = DESCRIPTOR.enum_types_by_name['RoleEnum']
RoleEnum = enum_type_wrapper.EnumTypeWrapper(_ROLEENUM)
_FRAMETYPEENUM = DESCRIPTOR.enum_types_by_name['FrameTypeEnum']
FrameTypeEnum = enum_type_wrapper.EnumTypeWrapper(_FRAMETYPEENUM)
_JOBSTATUSENUM = DESCRIPTOR.enum_types_by_name['JobStatusEnum']
JobStatusEnum = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUSENUM)
_QUERYEDGEDIRECTION = DESCRIPTOR.enum_types_by_name['QueryEdgeDirection']
QueryEdgeDirection = enum_type_wrapper.EnumTypeWrapper(_QUERYEDGEDIRECTION)
UNKNOWN_UVAL_TYPE = 0
UNKNOWN = 1
BOOLEAN = 2
INT = 3
FLOAT = 4
DATE = 5
TIME = 6
DATETIME = 7
IPADDRESS = 8
TEXT = 9
CONTAINER_ID = 10
JOB_ID = 11
LIST = 12
ROW_ID = 13
DURATION = 14
PROPERTY = 0
VERTEX_KEY = 1
EDGE_SOURCE_KEY = 2
EDGE_TARGET_KEY = 3
ASSOCIATIVE_CONTAINER_KEY = 4
TABLE = 0
VERTEX = 1
EDGE = 2
UVAL_ASSOCIATIVE = 3
UNKNOWN_JOB_STATUS = 0
SCHEDULED = 1
RUNNING = 2
COMPLETED = 3
CANCELED = 4
FAILED = 5
ROLLBACK = 6
FORWARD = 0
BACKWARD = 1
NOT_EDGE = 2


_PROPERTY = DESCRIPTOR.message_types_by_name['Property']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_TABLEFRAME = DESCRIPTOR.message_types_by_name['TableFrame']
_VERTEXFRAME = DESCRIPTOR.message_types_by_name['VertexFrame']
_EDGEFRAME = DESCRIPTOR.message_types_by_name['EdgeFrame']
_ANYFRAME = DESCRIPTOR.message_types_by_name['AnyFrame']
_QUERYEDGEMESSAGE = DESCRIPTOR.message_types_by_name['QueryEdgeMessage']
_QUERYEDGELIST = DESCRIPTOR.message_types_by_name['QueryEdgeList']
_QUERYPLAN = DESCRIPTOR.message_types_by_name['QueryPlan']
_JOBSTATUS = DESCRIPTOR.message_types_by_name['JobStatus']
_JOBSTATUS_VISITEDEDGESENTRY = _JOBSTATUS.nested_types_by_name['VisitedEdgesEntry']
Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Property)
  })
_sym_db.RegisterMessage(Property)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Schema)
  })
_sym_db.RegisterMessage(Schema)

TableFrame = _reflection.GeneratedProtocolMessageType('TableFrame', (_message.Message,), {
  'DESCRIPTOR' : _TABLEFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TableFrame)
  })
_sym_db.RegisterMessage(TableFrame)

VertexFrame = _reflection.GeneratedProtocolMessageType('VertexFrame', (_message.Message,), {
  'DESCRIPTOR' : _VERTEXFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VertexFrame)
  })
_sym_db.RegisterMessage(VertexFrame)

EdgeFrame = _reflection.GeneratedProtocolMessageType('EdgeFrame', (_message.Message,), {
  'DESCRIPTOR' : _EDGEFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EdgeFrame)
  })
_sym_db.RegisterMessage(EdgeFrame)

AnyFrame = _reflection.GeneratedProtocolMessageType('AnyFrame', (_message.Message,), {
  'DESCRIPTOR' : _ANYFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AnyFrame)
  })
_sym_db.RegisterMessage(AnyFrame)

QueryEdgeMessage = _reflection.GeneratedProtocolMessageType('QueryEdgeMessage', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEDGEMESSAGE,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.QueryEdgeMessage)
  })
_sym_db.RegisterMessage(QueryEdgeMessage)

QueryEdgeList = _reflection.GeneratedProtocolMessageType('QueryEdgeList', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEDGELIST,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.QueryEdgeList)
  })
_sym_db.RegisterMessage(QueryEdgeList)

QueryPlan = _reflection.GeneratedProtocolMessageType('QueryPlan', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPLAN,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.QueryPlan)
  })
_sym_db.RegisterMessage(QueryPlan)

JobStatus = _reflection.GeneratedProtocolMessageType('JobStatus', (_message.Message,), {

  'VisitedEdgesEntry' : _reflection.GeneratedProtocolMessageType('VisitedEdgesEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBSTATUS_VISITEDEDGESENTRY,
    '__module__' : 'SchemaMessages_pb2'
    # @@protoc_insertion_point(class_scope:xgt.JobStatus.VisitedEdgesEntry)
    })
  ,
  'DESCRIPTOR' : _JOBSTATUS,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.JobStatus)
  })
_sym_db.RegisterMessage(JobStatus)
_sym_db.RegisterMessage(JobStatus.VisitedEdgesEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOBSTATUS_VISITEDEDGESENTRY._options = None
  _JOBSTATUS_VISITEDEDGESENTRY._serialized_options = b'8\001'
  _UVALTYPEENUM._serialized_start=1576
  _UVALTYPEENUM._serialized_end=1784
  _ROLEENUM._serialized_start=1786
  _ROLEENUM._serialized_end=1899
  _FRAMETYPEENUM._serialized_start=1901
  _FRAMETYPEENUM._serialized_end=1971
  _JOBSTATUSENUM._serialized_start=1973
  _JOBSTATUSENUM._serialized_end=2095
  _QUERYEDGEDIRECTION._serialized_start=2097
  _QUERYEDGEDIRECTION._serialized_end=2158
  _PROPERTY._serialized_start=84
  _PROPERTY._serialized_end=233
  _SCHEMA._serialized_start=235
  _SCHEMA._serialized_end=276
  _TABLEFRAME._serialized_start=278
  _TABLEFRAME._serialized_end=333
  _VERTEXFRAME._serialized_start=335
  _VERTEXFRAME._serialized_end=391
  _EDGEFRAME._serialized_start=394
  _EDGEFRAME._serialized_end=534
  _ANYFRAME._serialized_start=537
  _ANYFRAME._serialized_end=736
  _QUERYEDGEMESSAGE._serialized_start=739
  _QUERYEDGEMESSAGE._serialized_end=934
  _QUERYEDGELIST._serialized_start=936
  _QUERYEDGELIST._serialized_end=1029
  _QUERYPLAN._serialized_start=1031
  _QUERYPLAN._serialized_end=1089
  _JOBSTATUS._serialized_start=1092
  _JOBSTATUS._serialized_end=1573
  _JOBSTATUS_VISITEDEDGESENTRY._serialized_start=1522
  _JOBSTATUS_VISITEDEDGESENTRY._serialized_end=1573
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: JobService.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10JobService.proto\x12\x03xgt\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\"\xba\x02\n\x19ScheduleJobsCypherRequest\x12\x14\n\x0c\x63ypher_query\x18\x01 \x03(\t\x12:\n\x06kwargs\x18\x05 \x03(\x0b\x32*.xgt.ScheduleJobsCypherRequest.KwargsEntry\x12\x42\n\nparameters\x18\x06 \x03(\x0b\x32..xgt.ScheduleJobsCypherRequest.ParametersEntry\x1a?\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\x1a\x46\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.xgt.ParameterValue:\x02\x38\x01\"[\n\x1aScheduleJobsCypherResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\"#\n\x11\x43\x61ncelJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\"S\n\x12\x43\x61ncelJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\" \n\x0eGetJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\"P\n\x0fGetJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"2\n\x0fWaitJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"Q\n\x10WaitJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus2\x9b\x02\n\nJobService\x12W\n\x12ScheduleJobsCypher\x12\x1e.xgt.ScheduleJobsCypherRequest\x1a\x1f.xgt.ScheduleJobsCypherResponse\"\x00\x12?\n\nCancelJobs\x12\x16.xgt.CancelJobsRequest\x1a\x17.xgt.CancelJobsResponse\"\x00\x12\x38\n\x07GetJobs\x12\x13.xgt.GetJobsRequest\x1a\x14.xgt.GetJobsResponse\"\x00\x30\x01\x12\x39\n\x08WaitJobs\x12\x14.xgt.WaitJobsRequest\x1a\x15.xgt.WaitJobsResponse\"\x00\x62\x06proto3')



_SCHEDULEJOBSCYPHERREQUEST = DESCRIPTOR.message_types_by_name['ScheduleJobsCypherRequest']
_SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY = _SCHEDULEJOBSCYPHERREQUEST.nested_types_by_name['KwargsEntry']
_SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY = _SCHEDULEJOBSCYPHERREQUEST.nested_types_by_name['ParametersEntry']
_SCHEDULEJOBSCYPHERRESPONSE = DESCRIPTOR.message_types_by_name['ScheduleJobsCypherResponse']
_CANCELJOBSREQUEST = DESCRIPTOR.message_types_by_name['CancelJobsRequest']
_CANCELJOBSRESPONSE = DESCRIPTOR.message_types_by_name['CancelJobsResponse']
_GETJOBSREQUEST = DESCRIPTOR.message_types_by_name['GetJobsRequest']
_GETJOBSRESPONSE = DESCRIPTOR.message_types_by_name['GetJobsResponse']
_WAITJOBSREQUEST = DESCRIPTOR.message_types_by_name['WaitJobsRequest']
_WAITJOBSRESPONSE = DESCRIPTOR.message_types_by_name['WaitJobsResponse']
ScheduleJobsCypherRequest = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherRequest', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY,
    '__module__' : 'JobService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest.KwargsEntry)
    })
  ,

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY,
    '__module__' : 'JobService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEDULEJOBSCYPHERREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest)
  })
_sym_db.RegisterMessage(ScheduleJobsCypherRequest)
_sym_db.RegisterMessage(ScheduleJobsCypherRequest.KwargsEntry)
_sym_db.RegisterMessage(ScheduleJobsCypherRequest.ParametersEntry)

ScheduleJobsCypherResponse = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherResponse', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEJOBSCYPHERRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherResponse)
  })
_sym_db.RegisterMessage(ScheduleJobsCypherResponse)

CancelJobsRequest = _reflection.GeneratedProtocolMessageType('CancelJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELJOBSREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsRequest)
  })
_sym_db.RegisterMessage(CancelJobsRequest)

CancelJobsResponse = _reflection.GeneratedProtocolMessageType('CancelJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELJOBSRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsResponse)
  })
_sym_db.RegisterMessage(CancelJobsResponse)

GetJobsRequest = _reflection.GeneratedProtocolMessageType('GetJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsRequest)
  })
_sym_db.RegisterMessage(GetJobsRequest)

GetJobsResponse = _reflection.GeneratedProtocolMessageType('GetJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsResponse)
  })
_sym_db.RegisterMessage(GetJobsResponse)

WaitJobsRequest = _reflection.GeneratedProtocolMessageType('WaitJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITJOBSREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.WaitJobsRequest)
  })
_sym_db.RegisterMessage(WaitJobsRequest)

WaitJobsResponse = _reflection.GeneratedProtocolMessageType('WaitJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WAITJOBSRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.WaitJobsResponse)
  })
_sym_db.RegisterMessage(WaitJobsResponse)

_JOBSERVICE = DESCRIPTOR.services_by_name['JobService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._options = None
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._serialized_options = b'8\001'
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._options = None
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _SCHEDULEJOBSCYPHERREQUEST._serialized_start=89
  _SCHEDULEJOBSCYPHERREQUEST._serialized_end=403
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._serialized_start=268
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._serialized_end=331
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._serialized_start=333
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._serialized_end=403
  _SCHEDULEJOBSCYPHERRESPONSE._serialized_start=405
  _SCHEDULEJOBSCYPHERRESPONSE._serialized_end=496
  _CANCELJOBSREQUEST._serialized_start=498
  _CANCELJOBSREQUEST._serialized_end=533
  _CANCELJOBSRESPONSE._serialized_start=535
  _CANCELJOBSRESPONSE._serialized_end=618
  _GETJOBSREQUEST._serialized_start=620
  _GETJOBSREQUEST._serialized_end=652
  _GETJOBSRESPONSE._serialized_start=654
  _GETJOBSRESPONSE._serialized_end=734
  _WAITJOBSREQUEST._serialized_start=736
  _WAITJOBSREQUEST._serialized_end=786
  _WAITJOBSRESPONSE._serialized_start=788
  _WAITJOBSRESPONSE._serialized_end=869
  _JOBSERVICE._serialized_start=872
  _JOBSERVICE._serialized_end=1155
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AdminService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x41\x64minService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\"#\n\x0bStringArray\x12\x14\n\x0cstring_value\x18\x01 \x03(\t\"\x15\n\x04\x44\x61te\x12\r\n\x05value\x18\x01 \x01(\t\"\x15\n\x04Time\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44\x61teTime\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44uration\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\tIPAddress\x12\r\n\x05value\x18\x01 \x01(\t\"\xad\x02\n\tParameter\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12\x1f\n\ndate_value\x18\x05 \x01(\x0b\x32\t.xgt.DateH\x00\x12\x1f\n\ntime_value\x18\x06 \x01(\x0b\x32\t.xgt.TimeH\x00\x12\'\n\x0e\x64\x61tetime_value\x18\x07 \x01(\x0b\x32\r.xgt.DateTimeH\x00\x12)\n\x0fipaddress_value\x18\x08 \x01(\x0b\x32\x0e.xgt.IPAddressH\x00\x12\'\n\x0e\x64uration_value\x18\t \x01(\x0b\x32\r.xgt.DurationH\x00\x42\x07\n\x05value\"/\n\x0eParameterValue\x12\x1d\n\x05value\x18\x01 \x03(\x0b\x32\x0e.xgt.Parameter\"p\n\x0b\x43onfigValue\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x42\x07\n\x05value\"D\n\x17\x43hangeErrorCountRequest\x12)\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x19.xgt.ErrorCountActionEnum\"J\n\x18\x43hangeErrorCountResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"\x1b\n\x19\x46reeUserMemorySizeRequest\"Q\n\x1a\x46reeUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"\x1a\n\x18MaxUserMemorySizeRequest\"I\n\x19MaxUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\" \n\x0fShutdownRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\"-\n\x10ShutdownResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x10\n\x0eVersionRequest\"=\n\x0fVersionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07version\x18\x02 \x01(\t\":\n\x13\x41uthenticateRequest\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\x12\x0e\n\x06userid\x18\x02 \x01(\t\"H\n\x14\x41uthenticateResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\"G\n\x1bKerberosAuthenticateRequest\x12\x11\n\tkrb_token\x18\x01 \x01(\x0c\x12\x15\n\rsession_token\x18\x02 \x01(\t\"c\n\x1cKerberosAuthenticateResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x11\n\tkrb_token\x18\x03 \x01(\x0c\"\x15\n\x13\x43loseSessionRequest\"1\n\x14\x43loseSessionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x1f\n\x10GetConfigRequest\x12\x0b\n\x03key\x18\x01 \x03(\t\"\xa6\x01\n\x11GetConfigResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x34\n\x07\x65ntries\x18\x02 \x03(\x0b\x32#.xgt.GetConfigResponse.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"\x89\x01\n\x10SetConfigRequest\x12\x33\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\".xgt.SetConfigRequest.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\".\n\x11SetConfigResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"7\n\x1aSetDefaultNamespaceRequest\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x01 \x01(\t\"8\n\x1bSetDefaultNamespaceResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x1c\n\x1aGetDefaultNamespaceRequest\"S\n\x1bGetDefaultNamespaceResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x02 \x01(\t*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xa4\x07\n\x0c\x41\x64minService\x12Q\n\x10\x43hangeErrorCount\x12\x1c.xgt.ChangeErrorCountRequest\x1a\x1d.xgt.ChangeErrorCountResponse\"\x00\x12W\n\x12\x46reeUserMemorySize\x12\x1e.xgt.FreeUserMemorySizeRequest\x1a\x1f.xgt.FreeUserMemorySizeResponse\"\x00\x12T\n\x11MaxUserMemorySize\x12\x1d.xgt.MaxUserMemorySizeRequest\x1a\x1e.xgt.MaxUserMemorySizeResponse\"\x00\x12\x39\n\x08Shutdown\x12\x14.xgt.ShutdownRequest\x1a\x15.xgt.ShutdownResponse\"\x00\x12\x36\n\x07Version\x12\x13.xgt.VersionRequest\x1a\x14.xgt.VersionResponse\"\x00\x12\x45\n\x0c\x41uthenticate\x12\x18.xgt.AuthenticateRequest\x1a\x19.xgt.AuthenticateResponse\"\x00\x12]\n\x14KerberosAuthenticate\x12 .xgt.KerberosAuthenticateRequest\x1a!.xgt.KerberosAuthenticateResponse\"\x00\x12\x45\n\x0c\x43loseSession\x12\x18.xgt.CloseSessionRequest\x1a\x19.xgt.CloseSessionResponse\"\x00\x12<\n\tGetConfig\x12\x15.xgt.GetConfigRequest\x1a\x16.xgt.GetConfigResponse\"\x00\x12<\n\tSetConfig\x12\x15.xgt.SetConfigRequest\x1a\x16.xgt.SetConfigResponse\"\x00\x12Z\n\x13SetDefaultNamespace\x12\x1f.xgt.SetDefaultNamespaceRequest\x1a .xgt.SetDefaultNamespaceResponse\"\x00\x12Z\n\x13GetDefaultNamespace\x12\x1f.xgt.GetDefaultNamespaceRequest\x1a .xgt.GetDefaultNamespaceResponse\"\x00\x62\x06proto3')

_ERRORCOUNTACTIONENUM = DESCRIPTOR.enum_types_by_name['ErrorCountActionEnum']
ErrorCountActionEnum = enum_type_wrapper.EnumTypeWrapper(_ERRORCOUNTACTIONENUM)
UNKNOWN_ERROR_COUNT_ACTION = 0
INCREMENT = 1
DECREMENT = 2


_STRINGARRAY = DESCRIPTOR.message_types_by_name['StringArray']
_DATE = DESCRIPTOR.message_types_by_name['Date']
_TIME = DESCRIPTOR.message_types_by_name['Time']
_DATETIME = DESCRIPTOR.message_types_by_name['DateTime']
_DURATION = DESCRIPTOR.message_types_by_name['Duration']
_IPADDRESS = DESCRIPTOR.message_types_by_name['IPAddress']
_PARAMETER = DESCRIPTOR.message_types_by_name['Parameter']
_PARAMETERVALUE = DESCRIPTOR.message_types_by_name['ParameterValue']
_CONFIGVALUE = DESCRIPTOR.message_types_by_name['ConfigValue']
_CHANGEERRORCOUNTREQUEST = DESCRIPTOR.message_types_by_name['ChangeErrorCountRequest']
_CHANGEERRORCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['ChangeErrorCountResponse']
_FREEUSERMEMORYSIZEREQUEST = DESCRIPTOR.message_types_by_name['FreeUserMemorySizeRequest']
_FREEUSERMEMORYSIZERESPONSE = DESCRIPTOR.message_types_by_name['FreeUserMemorySizeResponse']
_MAXUSERMEMORYSIZEREQUEST = DESCRIPTOR.message_types_by_name['MaxUserMemorySizeRequest']
_MAXUSERMEMORYSIZERESPONSE = DESCRIPTOR.message_types_by_name['MaxUserMemorySizeResponse']
_SHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['ShutdownRequest']
_SHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['ShutdownResponse']
_VERSIONREQUEST = DESCRIPTOR.message_types_by_name['VersionRequest']
_VERSIONRESPONSE = DESCRIPTOR.message_types_by_name['VersionResponse']
_AUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['AuthenticateRequest']
_AUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['AuthenticateResponse']
_KERBEROSAUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['KerberosAuthenticateRequest']
_KERBEROSAUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['KerberosAuthenticateResponse']
_CLOSESESSIONREQUEST = DESCRIPTOR.message_types_by_name['CloseSessionRequest']
_CLOSESESSIONRESPONSE = DESCRIPTOR.message_types_by_name['CloseSessionResponse']
_GETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetConfigRequest']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_GETCONFIGRESPONSE_ENTRIESENTRY = _GETCONFIGRESPONSE.nested_types_by_name['EntriesEntry']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_SETCONFIGREQUEST_ENTRIESENTRY = _SETCONFIGREQUEST.nested_types_by_name['EntriesEntry']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_SETDEFAULTNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['SetDefaultNamespaceRequest']
_SETDEFAULTNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['SetDefaultNamespaceResponse']
_GETDEFAULTNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetDefaultNamespaceRequest']
_GETDEFAULTNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['GetDefaultNamespaceResponse']
StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StringArray)
  })
_sym_db.RegisterMessage(StringArray)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Date)
  })
_sym_db.RegisterMessage(Date)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), {
  'DESCRIPTOR' : _TIME,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Time)
  })
_sym_db.RegisterMessage(Time)

DateTime = _reflection.GeneratedProtocolMessageType('DateTime', (_message.Message,), {
  'DESCRIPTOR' : _DATETIME,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DateTime)
  })
_sym_db.RegisterMessage(DateTime)

Duration = _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
  'DESCRIPTOR' : _DURATION,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Duration)
  })
_sym_db.RegisterMessage(Duration)

IPAddress = _reflection.GeneratedProtocolMessageType('IPAddress', (_message.Message,), {
  'DESCRIPTOR' : _IPADDRESS,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IPAddress)
  })
_sym_db.RegisterMessage(IPAddress)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

ParameterValue = _reflection.GeneratedProtocolMessageType('ParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERVALUE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ParameterValue)
  })
_sym_db.RegisterMessage(ParameterValue)

ConfigValue = _reflection.GeneratedProtocolMessageType('ConfigValue', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGVALUE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ConfigValue)
  })
_sym_db.RegisterMessage(ConfigValue)

ChangeErrorCountRequest = _reflection.GeneratedProtocolMessageType('ChangeErrorCountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEERRORCOUNTREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountRequest)
  })
_sym_db.RegisterMessage(ChangeErrorCountRequest)

ChangeErrorCountResponse = _reflection.GeneratedProtocolMessageType('ChangeErrorCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEERRORCOUNTRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountResponse)
  })
_sym_db.RegisterMessage(ChangeErrorCountResponse)

FreeUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _FREEUSERMEMORYSIZEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeRequest)
  })
_sym_db.RegisterMessage(FreeUserMemorySizeRequest)

FreeUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _FREEUSERMEMORYSIZERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeResponse)
  })
_sym_db.RegisterMessage(FreeUserMemorySizeResponse)

MaxUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAXUSERMEMORYSIZEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeRequest)
  })
_sym_db.RegisterMessage(MaxUserMemorySizeRequest)

MaxUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _MAXUSERMEMORYSIZERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeResponse)
  })
_sym_db.RegisterMessage(MaxUserMemorySizeResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

KerberosAuthenticateRequest = _reflection.GeneratedProtocolMessageType('KerberosAuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _KERBEROSAUTHENTICATEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.KerberosAuthenticateRequest)
  })
_sym_db.RegisterMessage(KerberosAuthenticateRequest)

KerberosAuthenticateResponse = _reflection.GeneratedProtocolMessageType('KerberosAuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _KERBEROSAUTHENTICATERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.KerberosAuthenticateResponse)
  })
_sym_db.RegisterMessage(KerberosAuthenticateResponse)

CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CloseSessionRequest)
  })
_sym_db.RegisterMessage(CloseSessionRequest)

CloseSessionResponse = _reflection.GeneratedProtocolMessageType('CloseSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CloseSessionResponse)
  })
_sym_db.RegisterMessage(CloseSessionResponse)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONFIGRESPONSE_ENTRIESENTRY,
    '__module__' : 'AdminService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.GetConfigResponse.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)
_sym_db.RegisterMessage(GetConfigResponse.EntriesEntry)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SETCONFIGREQUEST_ENTRIESENTRY,
    '__module__' : 'AdminService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.SetConfigRequest.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)
_sym_db.RegisterMessage(SetConfigRequest.EntriesEntry)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

SetDefaultNamespaceRequest = _reflection.GeneratedProtocolMessageType('SetDefaultNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTNAMESPACEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetDefaultNamespaceRequest)
  })
_sym_db.RegisterMessage(SetDefaultNamespaceRequest)

SetDefaultNamespaceResponse = _reflection.GeneratedProtocolMessageType('SetDefaultNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTNAMESPACERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetDefaultNamespaceResponse)
  })
_sym_db.RegisterMessage(SetDefaultNamespaceResponse)

GetDefaultNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetDefaultNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTNAMESPACEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetDefaultNamespaceRequest)
  })
_sym_db.RegisterMessage(GetDefaultNamespaceRequest)

GetDefaultNamespaceResponse = _reflection.GeneratedProtocolMessageType('GetDefaultNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTNAMESPACERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetDefaultNamespaceResponse)
  })
_sym_db.RegisterMessage(GetDefaultNamespaceResponse)

_ADMINSERVICE = DESCRIPTOR.services_by_name['AdminService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETCONFIGRESPONSE_ENTRIESENTRY._options = None
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_options = b'8\001'
  _SETCONFIGREQUEST_ENTRIESENTRY._options = None
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_options = b'8\001'
  _ERRORCOUNTACTIONENUM._serialized_start=2205
  _ERRORCOUNTACTIONENUM._serialized_end=2289
  _STRINGARRAY._serialized_start=48
  _STRINGARRAY._serialized_end=83
  _DATE._serialized_start=85
  _DATE._serialized_end=106
  _TIME._serialized_start=108
  _TIME._serialized_end=129
  _DATETIME._serialized_start=131
  _DATETIME._serialized_end=156
  _DURATION._serialized_start=158
  _DURATION._serialized_end=183
  _IPADDRESS._serialized_start=185
  _IPADDRESS._serialized_end=211
  _PARAMETER._serialized_start=214
  _PARAMETER._serialized_end=515
  _PARAMETERVALUE._serialized_start=517
  _PARAMETERVALUE._serialized_end=564
  _CONFIGVALUE._serialized_start=566
  _CONFIGVALUE._serialized_end=678
  _CHANGEERRORCOUNTREQUEST._serialized_start=680
  _CHANGEERRORCOUNTREQUEST._serialized_end=748
  _CHANGEERRORCOUNTRESPONSE._serialized_start=750
  _CHANGEERRORCOUNTRESPONSE._serialized_end=824
  _FREEUSERMEMORYSIZEREQUEST._serialized_start=826
  _FREEUSERMEMORYSIZEREQUEST._serialized_end=853
  _FREEUSERMEMORYSIZERESPONSE._serialized_start=855
  _FREEUSERMEMORYSIZERESPONSE._serialized_end=936
  _MAXUSERMEMORYSIZEREQUEST._serialized_start=938
  _MAXUSERMEMORYSIZEREQUEST._serialized_end=964
  _MAXUSERMEMORYSIZERESPONSE._serialized_start=966
  _MAXUSERMEMORYSIZERESPONSE._serialized_end=1039
  _SHUTDOWNREQUEST._serialized_start=1041
  _SHUTDOWNREQUEST._serialized_end=1073
  _SHUTDOWNRESPONSE._serialized_start=1075
  _SHUTDOWNRESPONSE._serialized_end=1120
  _VERSIONREQUEST._serialized_start=1122
  _VERSIONREQUEST._serialized_end=1138
  _VERSIONRESPONSE._serialized_start=1140
  _VERSIONRESPONSE._serialized_end=1201
  _AUTHENTICATEREQUEST._serialized_start=1203
  _AUTHENTICATEREQUEST._serialized_end=1261
  _AUTHENTICATERESPONSE._serialized_start=1263
  _AUTHENTICATERESPONSE._serialized_end=1335
  _KERBEROSAUTHENTICATEREQUEST._serialized_start=1337
  _KERBEROSAUTHENTICATEREQUEST._serialized_end=1408
  _KERBEROSAUTHENTICATERESPONSE._serialized_start=1410
  _KERBEROSAUTHENTICATERESPONSE._serialized_end=1509
  _CLOSESESSIONREQUEST._serialized_start=1511
  _CLOSESESSIONREQUEST._serialized_end=1532
  _CLOSESESSIONRESPONSE._serialized_start=1534
  _CLOSESESSIONRESPONSE._serialized_end=1583
  _GETCONFIGREQUEST._serialized_start=1585
  _GETCONFIGREQUEST._serialized_end=1616
  _GETCONFIGRESPONSE._serialized_start=1619
  _GETCONFIGRESPONSE._serialized_end=1785
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_start=1721
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_end=1785
  _SETCONFIGREQUEST._serialized_start=1788
  _SETCONFIGREQUEST._serialized_end=1925
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_start=1721
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_end=1785
  _SETCONFIGRESPONSE._serialized_start=1927
  _SETCONFIGRESPONSE._serialized_end=1973
  _SETDEFAULTNAMESPACEREQUEST._serialized_start=1975
  _SETDEFAULTNAMESPACEREQUEST._serialized_end=2030
  _SETDEFAULTNAMESPACERESPONSE._serialized_start=2032
  _SETDEFAULTNAMESPACERESPONSE._serialized_end=2088
  _GETDEFAULTNAMESPACEREQUEST._serialized_start=2090
  _GETDEFAULTNAMESPACEREQUEST._serialized_end=2118
  _GETDEFAULTNAMESPACERESPONSE._serialized_start=2120
  _GETDEFAULTNAMESPACERESPONSE._serialized_end=2203
  _ADMINSERVICE._serialized_start=2292
  _ADMINSERVICE._serialized_end=3224
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*- --------------------------------------------------===#
#
#  Copyright 2018-2023 Trovares Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#
#===----------------------------------------------------------------------===#

import os.path
from setuptools import setup, find_packages

basedir = os.path.dirname(__file__)
with open(os.path.join(basedir,'requirements.txt')) as f:
  requirements = f.read().splitlines()

setup(packages=find_packages('src'),
      package_dir={'':'src'},
      include_package_data=True,
      install_requires=requirements,
      extras_require={
        'extra': ['pandas>=0.24.2', 'jupyter'],
      }
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DataService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x44\x61taService.proto\x12\x03xgt\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\x1a\x1egoogle/protobuf/wrappers.proto\"N\n\x17\x46rameColumnToSourceName\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x18\n\x10\x66ile_column_name\x18\x02 \x01(\t\"L\n\x16\x46rameColumnToSourceIdx\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_column_idx\x18\x02 \x01(\x04\"\xa8\x01\n\rColumnMapping\x12\x41\n\x1b\x66rame_column_to_source_name\x18\x01 \x03(\x0b\x32\x1c.xgt.FrameColumnToSourceName\x12?\n\x1a\x66rame_column_to_source_idx\x18\x02 \x03(\x0b\x32\x1b.xgt.FrameColumnToSourceIdx\x12\x13\n\x0bhas_mapping\x18\x03 \x01(\x08\"\xb1\x01\n\x17UploadRowLevelLabelInfo\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x1c\n\x14label_column_indices\x18\x02 \x03(\x03\x12\x1a\n\x12label_column_names\x18\x03 \x03(\t\x12%\n\x1dimplicit_source_vertex_labels\x18\x04 \x03(\t\x12%\n\x1dimplicit_target_vertex_labels\x18\x05 \x03(\t\"L\n\x19\x44ownloadRowLevelLabelInfo\x12\x14\n\x0c\x65gest_labels\x18\x01 \x01(\x08\x12\x19\n\x11label_header_name\x18\x02 \x01(\t\"\x8e\x03\n\x11UploadDataRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12&\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x10.xgt.ContentType\x12(\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x15\n\rauthorization\x18\x05 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x06 \x01(\x08\x12\x30\n\nrow_labels\x18\x07 \x01(\x0b\x32\x1c.xgt.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12\x18\n\x10is_python_insert\x18\t \x01(\x08\x12\x11\n\tfile_path\x18\n \x01(\t\x12*\n\x0e\x63olumn_mapping\x18\x0b \x01(\x0b\x32\x12.xgt.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\x0c \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\r \x01(\t\"S\n\x12UploadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"\xc5\x02\n\x13\x44ownloadDataRequest\x12\x17\n\x0frepository_name\x18\x01 \x01(\t\x12,\n\x06offset\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x14\n\x0cwith_headers\x18\x04 \x01(\x08\x12&\n\x0c\x63ontent_type\x18\x05 \x01(\x0e\x32\x10.xgt.ContentType\x12\x32\n\nrow_labels\x18\x08 \x01(\x0b\x32\x1e.xgt.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\t \x01(\x08\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\"~\n\x14\x44ownloadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\"\n\njob_status\x18\x03 \x01(\x0b\x32\x0e.xgt.JobStatus\x12\x16\n\x0enum_row_labels\x18\x04 \x01(\x05\"\xb0\x03\n\x10IngestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x02 \x03(\t\x12(\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x15\n\rauthorization\x18\x04 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x05 \x01(\x08\x12\x31\n\x06kwargs\x18\x06 \x03(\x0b\x32!.xgt.IngestUriRequest.KwargsEntry\x12\x30\n\nrow_labels\x18\x07 \x01(\x0b\x32\x1c.xgt.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12*\n\x0e\x63olumn_mapping\x18\t \x01(\x0b\x32\x12.xgt.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\n \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\x0b \x01(\t\x1a?\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"R\n\x11IngestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"\xb3\x03\n\x0f\x45gestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x14\n\x0cwith_headers\x18\x03 \x01(\x08\x12\x30\n\x06kwargs\x18\x04 \x03(\x0b\x32 .xgt.EgestUriRequest.KwargsEntry\x12\x32\n\nrow_labels\x18\x05 \x01(\x0b\x32\x1e.xgt.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\x06 \x01(\x08\x12\x17\n\x0fnumber_of_files\x18\x07 \x01(\x04\x12,\n\x06offset\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\x1a?\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"Q\n\x10\x45gestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"d\n\x12InferSchemaRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12(\n\x0bheader_mode\x18\x02 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x11\n\tdelimiter\x18\x03 \x01(\t\"M\n\x13InferSchemaResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\"m\n\x07SSLInfo\x12\x0e\n\x06\x64o_ssl\x18\x01 \x01(\x08\x12\x12\n\nchain_cert\x18\x02 \x01(\x0c\x12\x12\n\nclient_key\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63lient_cert\x18\x04 \x01(\x0c\x12\x15\n\rssl_server_cn\x18\x05 \x01(\t\"3\n\x0cUserAuthInfo\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x97\x01\n\x1fTransferFrameArrowClientRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x04\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12\x19\n\x03ssl\x18\x04 \x01(\x0b\x32\x0c.xgt.SSLInfo\x12$\n\tuser_auth\x18\x05 \x01(\x0b\x32\x11.xgt.UserAuthInfo\"a\n TransferFrameArrowClientResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus*_\n\x0eHeaderModeEnum\x12\x17\n\x13UNKNOWN_HEADER_MODE\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x12\n\x0eIGNORE_HEADERS\x10\x02\x12\n\n\x06NORMAL\x10\x03\x12\n\n\x06STRICT\x10\x04*R\n\x0b\x43ontentType\x12\x13\n\x0fUNKNOWN_CONTENT\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x07\n\x03ZIP\x10\x03\x12\x08\n\x04GZIP\x10\x04\x12\x08\n\x04TZIP\x10\x05\x32\xc1\x03\n\x0b\x44\x61taService\x12\x41\n\nUploadData\x12\x16.xgt.UploadDataRequest\x1a\x17.xgt.UploadDataResponse\"\x00(\x01\x12G\n\x0c\x44ownloadData\x12\x18.xgt.DownloadDataRequest\x1a\x19.xgt.DownloadDataResponse\"\x00\x30\x01\x12<\n\tIngestUri\x12\x15.xgt.IngestUriRequest\x1a\x16.xgt.IngestUriResponse\"\x00\x12\x39\n\x08\x45gestUri\x12\x14.xgt.EgestUriRequest\x1a\x15.xgt.EgestUriResponse\"\x00\x12\x42\n\x0bInferSchema\x12\x17.xgt.InferSchemaRequest\x1a\x18.xgt.InferSchemaResponse\"\x00\x12i\n\x18TransferFrameArrowClient\x12$.xgt.TransferFrameArrowClientRequest\x1a%.xgt.TransferFrameArrowClientResponse\"\x00\x62\x06proto3')

_HEADERMODEENUM = DESCRIPTOR.enum_types_by_name['HeaderModeEnum']
HeaderModeEnum = enum_type_wrapper.EnumTypeWrapper(_HEADERMODEENUM)
_CONTENTTYPE = DESCRIPTOR.enum_types_by_name['ContentType']
ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN_HEADER_MODE = 0
NONE = 1
IGNORE_HEADERS = 2
NORMAL = 3
STRICT = 4
UNKNOWN_CONTENT = 0
CSV = 1
JSON = 2
ZIP = 3
GZIP = 4
TZIP = 5


_FRAMECOLUMNTOSOURCENAME = DESCRIPTOR.message_types_by_name['FrameColumnToSourceName']
_FRAMECOLUMNTOSOURCEIDX = DESCRIPTOR.message_types_by_name['FrameColumnToSourceIdx']
_COLUMNMAPPING = DESCRIPTOR.message_types_by_name['ColumnMapping']
_UPLOADROWLEVELLABELINFO = DESCRIPTOR.message_types_by_name['UploadRowLevelLabelInfo']
_DOWNLOADROWLEVELLABELINFO = DESCRIPTOR.message_types_by_name['DownloadRowLevelLabelInfo']
_UPLOADDATAREQUEST = DESCRIPTOR.message_types_by_name['UploadDataRequest']
_UPLOADDATARESPONSE = DESCRIPTOR.message_types_by_name['UploadDataResponse']
_DOWNLOADDATAREQUEST = DESCRIPTOR.message_types_by_name['DownloadDataRequest']
_DOWNLOADDATARESPONSE = DESCRIPTOR.message_types_by_name['DownloadDataResponse']
_INGESTURIREQUEST = DESCRIPTOR.message_types_by_name['IngestUriRequest']
_INGESTURIREQUEST_KWARGSENTRY = _INGESTURIREQUEST.nested_types_by_name['KwargsEntry']
_INGESTURIRESPONSE = DESCRIPTOR.message_types_by_name['IngestUriResponse']
_EGESTURIREQUEST = DESCRIPTOR.message_types_by_name['EgestUriRequest']
_EGESTURIREQUEST_KWARGSENTRY = _EGESTURIREQUEST.nested_types_by_name['KwargsEntry']
_EGESTURIRESPONSE = DESCRIPTOR.message_types_by_name['EgestUriResponse']
_INFERSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['InferSchemaRequest']
_INFERSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['InferSchemaResponse']
_SSLINFO = DESCRIPTOR.message_types_by_name['SSLInfo']
_USERAUTHINFO = DESCRIPTOR.message_types_by_name['UserAuthInfo']
_TRANSFERFRAMEARROWCLIENTREQUEST = DESCRIPTOR.message_types_by_name['TransferFrameArrowClientRequest']
_TRANSFERFRAMEARROWCLIENTRESPONSE = DESCRIPTOR.message_types_by_name['TransferFrameArrowClientResponse']
FrameColumnToSourceName = _reflection.GeneratedProtocolMessageType('FrameColumnToSourceName', (_message.Message,), {
  'DESCRIPTOR' : _FRAMECOLUMNTOSOURCENAME,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FrameColumnToSourceName)
  })
_sym_db.RegisterMessage(FrameColumnToSourceName)

FrameColumnToSourceIdx = _reflection.GeneratedProtocolMessageType('FrameColumnToSourceIdx', (_message.Message,), {
  'DESCRIPTOR' : _FRAMECOLUMNTOSOURCEIDX,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FrameColumnToSourceIdx)
  })
_sym_db.RegisterMessage(FrameColumnToSourceIdx)

ColumnMapping = _reflection.GeneratedProtocolMessageType('ColumnMapping', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNMAPPING,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ColumnMapping)
  })
_sym_db.RegisterMessage(ColumnMapping)

UploadRowLevelLabelInfo = _reflection.GeneratedProtocolMessageType('UploadRowLevelLabelInfo', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADROWLEVELLABELINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadRowLevelLabelInfo)
  })
_sym_db.RegisterMessage(UploadRowLevelLabelInfo)

DownloadRowLevelLabelInfo = _reflection.GeneratedProtocolMessageType('DownloadRowLevelLabelInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADROWLEVELLABELINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadRowLevelLabelInfo)
  })
_sym_db.RegisterMessage(DownloadRowLevelLabelInfo)

UploadDataRequest = _reflection.GeneratedProtocolMessageType('UploadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDATAREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataRequest)
  })
_sym_db.RegisterMessage(UploadDataRequest)

UploadDataResponse = _reflection.GeneratedProtocolMessageType('UploadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDATARESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataResponse)
  })
_sym_db.RegisterMessage(UploadDataResponse)

DownloadDataRequest = _reflection.GeneratedProtocolMessageType('DownloadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATAREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataRequest)
  })
_sym_db.RegisterMessage(DownloadDataRequest)

DownloadDataResponse = _reflection.GeneratedProtocolMessageType('DownloadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATARESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataResponse)
  })
_sym_db.RegisterMessage(DownloadDataResponse)

IngestUriRequest = _reflection.GeneratedProtocolMessageType('IngestUriRequest', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INGESTURIREQUEST_KWARGSENTRY,
    '__module__' : 'DataService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.IngestUriRequest.KwargsEntry)
    })
  ,
  'DESCRIPTOR' : _INGESTURIREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriRequest)
  })
_sym_db.RegisterMessage(IngestUriRequest)
_sym_db.RegisterMessage(IngestUriRequest.KwargsEntry)

IngestUriResponse = _reflection.GeneratedProtocolMessageType('IngestUriResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTURIRESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriResponse)
  })
_sym_db.RegisterMessage(IngestUriResponse)

EgestUriRequest = _reflection.GeneratedProtocolMessageType('EgestUriRequest', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EGESTURIREQUEST_KWARGSENTRY,
    '__module__' : 'DataService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.EgestUriRequest.KwargsEntry)
    })
  ,
  'DESCRIPTOR' : _EGESTURIREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriRequest)
  })
_sym_db.RegisterMessage(EgestUriRequest)
_sym_db.RegisterMessage(EgestUriRequest.KwargsEntry)

EgestUriResponse = _reflection.GeneratedProtocolMessageType('EgestUriResponse', (_message.Message,), {
  'DESCRIPTOR' : _EGESTURIRESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriResponse)
  })
_sym_db.RegisterMessage(EgestUriResponse)

InferSchemaRequest = _reflection.GeneratedProtocolMessageType('InferSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMAREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.InferSchemaRequest)
  })
_sym_db.RegisterMessage(InferSchemaRequest)

InferSchemaResponse = _reflection.GeneratedProtocolMessageType('InferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMARESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.InferSchemaResponse)
  })
_sym_db.RegisterMessage(InferSchemaResponse)

SSLInfo = _reflection.GeneratedProtocolMessageType('SSLInfo', (_message.Message,), {
  'DESCRIPTOR' : _SSLINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SSLInfo)
  })
_sym_db.RegisterMessage(SSLInfo)

UserAuthInfo = _reflection.GeneratedProtocolMessageType('UserAuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERAUTHINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UserAuthInfo)
  })
_sym_db.RegisterMessage(UserAuthInfo)

TransferFrameArrowClientRequest = _reflection.GeneratedProtocolMessageType('TransferFrameArrowClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERFRAMEARROWCLIENTREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TransferFrameArrowClientRequest)
  })
_sym_db.RegisterMessage(TransferFrameArrowClientRequest)

TransferFrameArrowClientResponse = _reflection.GeneratedProtocolMessageType('TransferFrameArrowClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERFRAMEARROWCLIENTRESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TransferFrameArrowClientResponse)
  })
_sym_db.RegisterMessage(TransferFrameArrowClientResponse)

_DATASERVICE = DESCRIPTOR.services_by_name['DataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INGESTURIREQUEST_KWARGSENTRY._options = None
  _INGESTURIREQUEST_KWARGSENTRY._serialized_options = b'8\001'
  _EGESTURIREQUEST_KWARGSENTRY._options = None
  _EGESTURIREQUEST_KWARGSENTRY._serialized_options = b'8\001'
  _HEADERMODEENUM._serialized_start=3288
  _HEADERMODEENUM._serialized_end=3383
  _CONTENTTYPE._serialized_start=3385
  _CONTENTTYPE._serialized_end=3467
  _FRAMECOLUMNTOSOURCENAME._serialized_start=121
  _FRAMECOLUMNTOSOURCENAME._serialized_end=199
  _FRAMECOLUMNTOSOURCEIDX._serialized_start=201
  _FRAMECOLUMNTOSOURCEIDX._serialized_end=277
  _COLUMNMAPPING._serialized_start=280
  _COLUMNMAPPING._serialized_end=448
  _UPLOADROWLEVELLABELINFO._serialized_start=451
  _UPLOADROWLEVELLABELINFO._serialized_end=628
  _DOWNLOADROWLEVELLABELINFO._serialized_start=630
  _DOWNLOADROWLEVELLABELINFO._serialized_end=706
  _UPLOADDATAREQUEST._serialized_start=709
  _UPLOADDATAREQUEST._serialized_end=1107
  _UPLOADDATARESPONSE._serialized_start=1109
  _UPLOADDATARESPONSE._serialized_end=1192
  _DOWNLOADDATAREQUEST._serialized_start=1195
  _DOWNLOADDATAREQUEST._serialized_end=1520
  _DOWNLOADDATARESPONSE._serialized_start=1522
  _DOWNLOADDATARESPONSE._serialized_end=1648
  _INGESTURIREQUEST._serialized_start=1651
  _INGESTURIREQUEST._serialized_end=2083
  _INGESTURIREQUEST_KWARGSENTRY._serialized_start=2020
  _INGESTURIREQUEST_KWARGSENTRY._serialized_end=2083
  _INGESTURIRESPONSE._serialized_start=2085
  _INGESTURIRESPONSE._serialized_end=2167
  _EGESTURIREQUEST._serialized_start=2170
  _EGESTURIREQUEST._serialized_end=2605
  _EGESTURIREQUEST_KWARGSENTRY._serialized_start=2020
  _EGESTURIREQUEST_KWARGSENTRY._serialized_end=2083
  _EGESTURIRESPONSE._serialized_start=2607
  _EGESTURIRESPONSE._serialized_end=2688
  _INFERSCHEMAREQUEST._serialized_start=2690
  _INFERSCHEMAREQUEST._serialized_end=2790
  _INFERSCHEMARESPONSE._serialized_start=2792
  _INFERSCHEMARESPONSE._serialized_end=2869
  _SSLINFO._serialized_start=2871
  _SSLINFO._serialized_end=2980
  _USERAUTHINFO._serialized_start=2982
  _USERAUTHINFO._serialized_end=3033
  _TRANSFERFRAMEARROWCLIENTREQUEST._serialized_start=3036
  _TRANSFERFRAMEARROWCLIENTREQUEST._serialized_end=3187
  _TRANSFERFRAMEARROWCLIENTRESPONSE._serialized_start=3189
  _TRANSFERFRAMEARROWCLIENTRESPONSE._serialized_end=3286
  _DATASERVICE._serialized_start=3470
  _DATASERVICE._serialized_end=3919
# @@protoc_insertion_point(module_scope)
